# traxis

A Digital Framework for Analysis of Particle Bubble Chamber Tracks. Used in the
High Energy Physics experiment in UofT Advanced Labs.


## Description

Python-based toolkit with GUI that computes track momentum and optical density
of tracks in digitized bubble chamber images.

## Installing and Running

It can now be installed with pip:

```
pip install traxis
# Then run the command
runtraxis
```

Or, from source without installation,
on Linux, UNIX, Mac:

```
tar xzvf traxis-*.tar.gz
cd traxis
./runtraxis
```

On Windows:

- Extract traxis.zip
- Go to extracted traxis folder
- Execute runtraxis with Python 3

## Dependencies

- Python (3.3+)
- numpy
- scipy
- PyQt5 (5.3+)

## Authors

Syed Haider Abidi, Nooruddin Ahmed and Christopher Dydula
